FormatGroup

Struct FormatGroup 

pub struct FormatGroup(/* private fields */);
Available on crate feature pstoedit_4_00 only.
Format group of pstoedit driver.

Driver-specific options of pstoedit are specific to a format group. All drivers in a format group have an equal value of FormatGroup.